@@ -4,14 +4,10 @@
 #include <QInputDialog>
 #include <QDebug>
 #include "todomodel.h"
-#include "platutil.h"
-
 CategoryEditor::CategoryEditor(QWidget *parent) :
     QWidget(parent),
     ui(new Ui::CategoryEditor)
 {
-    PlatUtil::configureWindow(this);
-
     ui->setupUi(this);
     connect(ui->btnNewCat, SIGNAL(clicked()), this, SLOT(addCategory()));
     connect(ui->listWidget, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(selectCategory(QListWidgetItem*)));
