@@ -29,6 +29,8 @@ void CategorySelectorAction::doPopup()
     TodoModel* m = TodoModel::instance();
 
     connect(ce, SIGNAL(categorySelected(QString)), m, SLOT(setCurrentCategory(QString)));
+    ce->setAttribute(Qt::WA_Maemo5StackedWindow);
+    ce->setWindowFlags(ce->windowFlags() | Qt::Window);
     ce->show();
 
 }
