@@ -16,7 +16,6 @@
 #include <QMaemo5ListPickSelector>
 #include <QStandardItemModel>
 #include "filterselectoraction.h"
-#include "platutil.h"
 
 class FilterAction : public QWidgetAction
 {
@@ -41,8 +40,10 @@ FrontPage::FrontPage(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::FrontPage)
 {
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5StackedWindow);
+#endif
 
-    PlatUtil::configureWindow(this);
     //m_catselector = new
     TodoModel* mdl = TodoModel::instance();
     ui->setupUi(this);
@@ -54,6 +55,15 @@ FrontPage::FrontPage(QWidget *parent) :
 
     CategorySelectorAction* filt = new CategorySelectorAction(this);
 
+    /*
+    m_catselector = new QMaemo5ValueButton(this);
+    m_catselector->setText("foo");
+    m_catselector->setValueText("bar");
+
+    QWidgetAction* wa = new QWidgetAction(this);
+
+    wa->setDefaultWidget(m_catselector);
+    */
     menuBar()->addAction(filt);
     setWindowTitle("Qtdone - INBOX");
 
@@ -158,13 +168,6 @@ void FrontPage::populate()
 
     m->getTasksForFolder("inbox", tasks);
 
-    if (tasks.isEmpty()) {
-        m->getTasksForFolder("Now", tasks);
-        setWindowTitle(m->windowTitle("Qtd Now"));
-    } else {
-        setWindowTitle(m->windowTitle("Qtd In"));
-    }
-
     ui->inboxListWidget->clear();
     foreach (const TaskEntry& t, tasks) {
         QListWidgetItem* it = new QListWidgetItem(t.desc);
@@ -172,6 +175,7 @@ void FrontPage::populate()
         it->setData(Qt::UserRole, t.id);
         ui->inboxListWidget->addItem(it);
     }
+    setWindowTitle(m->windowTitle("Qtd In"));
 }
 
 void FrontPage::itemSelected(QListWidgetItem *item)
@@ -190,7 +194,7 @@ void FrontPage::itemSelected(QListWidgetItem *item)
 
 void FrontPage::folderUpdated(const QString &folder)
 {
-    if (folder == "inbox" || folder == "Now") {
+    if (folder == "inbox") {
         populate();
     }
 }
